function S = ReadImageSequence(filename)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Read image sequence in current directory and put them into cell S
% If no argument is given, it will read all .tif files in the folder,
% assuming each .tif contains one image
% If 1 argument is given, it will read .tif file pointed by the argument
% assuming it is stacked tiff (i.e. it contains many images in one .tif
% file)
%
%   Created by: Jeremy Hadidjojo (hjeremy@umich.edu), 07/06/2013
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if nargin == 0
    list = dir('*.tif');
    fnames = cat(1, list.name);
    n = size(fnames, 1);

    S = cell(n,1);
    for i = 1:n
        S{i} = imread(fnames(i,:));
    end

    
elseif nargin == 1
    Info = imfinfo(filename);
    temp = cat(1, Info.Format);
    n = size(temp,1);
    
    S = cell(n,1);
    for i = 1:n
        S{i} = imread(filename, 'Index', i, 'Info', Info);
    end
end
